#
# spec file for package libnitrokey
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} == 1315
%define force_gcc_version 7
%endif
%define lib_name %{name}3

Name:           libnitrokey
Version:        3.8
Release:        1.7
Summary:        Communicate with Nitrokey stick devices in a clean and easy manner
License:        LGPL-3.0-only
Group:          Development/Libraries/C and C++
URL:            https://github.com/Nitrokey/libnitrokey
Source:         https://github.com/Nitrokey/libnitrokey/releases/download/v%{version}/libnitrokey-v%{version}.tar.gz
Source1:        https://github.com/Nitrokey/libnitrokey/releases/download/v%{version}/libnitrokey-v%{version}.tar.gz.sig
BuildRequires:  cmake
BuildRequires:  gcc%{?force_gcc_version}-c++ >= 5
%if 0%{?force_gcc_version}
#!BuildIgnore:  libgcc_s1
%endif
BuildRequires:  pkgconfig
BuildRequires:  python3-devel
BuildRequires:  pkgconfig(hidapi-libusb)
BuildRequires:  pkgconfig(libusb-1.0)
BuildRequires:  pkgconfig(udev)

%description
Libnitrokey is a project to communicate with Nitrokey Pro and Storage devices
in a clean and easy manner.

%package -n %{lib_name}
Summary:        Shared library for libnitrokey
Group:          Development/Libraries/C and C++
Requires:       %{name}-udev >= %{version}

%description -n %{lib_name}
Libnitrokey is a project to communicate with Nitrokey Pro and Storage devices
in a clean and easy manner.

This package holds the shared library.

%package udev
Summary:        udev rules for libnitrokey
Group:          Development/Libraries/C and C++
BuildArch:      noarch

%description udev
Libnitrokey is a project to communicate with Nitrokey Pro and Storage devices
in a clean and easy manner.

This package holds the udev rules.

%package devel
Summary:        Development files for libnitrokey
Group:          Development/Libraries/C and C++
Requires:       %{lib_name} = %{version}

%description devel
Libnitrokey is a project to communicate with Nitrokey Pro and Storage devices
in a clean and easy manner.

This package holds the development files.

%prep
%setup -q -n %{name}-v%{version}

%build
%if 0%{?force_gcc_version}
export CC="gcc-%{?force_gcc_version}"
export CXX="g++-%{?force_gcc_version}"
%endif
%cmake
make %{?_smp_mflags} CXX=g++

%install
%cmake_install

%post   -n %{lib_name} -p /sbin/ldconfig
%postun -n %{lib_name} -p /sbin/ldconfig

%files udev
%{_prefix}/lib/udev/rules.d/41-nitrokey.rules

%files devel
%{_includedir}/libnitrokey/
%{_libdir}/libnitrokey.so
%{_libdir}/pkgconfig/libnitrokey-1.pc

%files -n %{lib_name}
%{_libdir}/libnitrokey.so.*

%changelog
* Mon Nov 21 2022 Martin Sirringhaus <mark_nefedov@runbox.com>
- Update to 3.8
  * Udev rules update;
  * Build warnings fixes.
* Tue May  3 2022 Martin Sirringhaus <martin.sirringhaus@suse.com>
- Update to 3.7
  * Nitrokey Pro v0.14 support;
  * Udev rules update;
  * Stability fixes.
- drop udev-rules-add-nitrokey3.patch which is now upstream
* Mon Apr 25 2022 Marcus Meissner <meissner@suse.com>
- switch buildrequires udev to pkgconfig(udev).
* Mon Apr 25 2022 Martin Sirringhaus <martin.sirringhaus@suse.com>
- udev-rules-add-nitrokey3.patch
  Add rule for Nitrokey 3
* Wed Nov 25 2020 Marcus Rueckert <mrueckert@suse.de>
- update to 3.6
  - LibremKey and FreeBSD support. Extended API.
- drop UDEV-rule-for-FIDO2.patch:
  includes in update
* Tue Jul 14 2020 Michal Kubecek <mkubecek@suse.cz>
- UDEV-rule-for-FIDO2.patch
  add rule for Nitrokey FIDO2 device (20a0:42b1)
* Sat Feb 29 2020 Marcus Rueckert <mrueckert@suse.de>
- update to 3.5
  - Storage v0.54 support. Tests and documentation update.
* Tue Dec 11 2018 Marcus Rueckert <mrueckert@suse.de>
- update to 3.4.1
  - Version bump to 3.4 (not done in previous release).
  - Build from tarball (git describe was failing).
  - Handle version getting, when building with Qt (return constants
    for now).
  - API: deprecate NK_totp_get_time.
  - Add get_library_version().
  - Fix strdup issue, which causes memory leak in C API.
  - Corrected documentation and updated tests.
* Wed Apr 11 2018 mrueckert@suse.de
- require the udev rules with >= to get rid of the rpmlint warning
* Tue Apr 10 2018 mrueckert@suse.de
- force gcc 7 on leap 42.x
* Tue Apr 10 2018 mrueckert@suse.de
- added BR for pkgconfig(libusb-1.0)
* Tue Apr 10 2018 mrueckert@suse.de
- initial package (v3.3)
